#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : __init__.py
# @Time         : 2023/7/4 13:53
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from chatllm.llmchain.llms.basellm import BaseLLM

# from chatllm.llmchain.llms.ernie import ErnieBot
# from chatllm.llmchain.llms.spark import SparkBot
# from chatllm.llmchain.llms.chatglm import ChatGLM
# from chatllm.llmchain.llms.hunyuan import HuanYuan
# from chatllm.llmchain.llms.kimi import Kimi
